fnss.topologies.topology.Topology.remove_edges_from — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.topology.Topology.remove_edges_from

`Topology.` `remove_edges_from`(ebunch)

  Remove all edges specified in ebunch.

  Parameters : | ebunch: list or container of edge tuples : Each edge given in the list or container will be removed from the graph. The edges can be: 2-tuples (u,v) edge between u and v. 3-tuples (u,v,k) where k is ignored.

  See also

  `remove_edge`
    remove a single edge

  Notes

  Will fail silently if an edge in ebunch is not in the graph.

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> ebunch=[(1,2),(2,3)]
      >>> G.remove_edges_from(ebunch)

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »